// src/mdx-plugins/remark-headings.ts
import Slugger from "github-slugger";
import { visit } from "unist-util-visit";
import { MARKDOWN_EXTENSION_REGEX } from "../constants.mjs";
var getFlattenedValue = (node) => node.children.map(
  (child) => "children" in child ? getFlattenedValue(child) : "value" in child ? child.value : ""
).join("");
var SKIP_FOR_PARENT_NAMES = /* @__PURE__ */ new Set(["Tab", "Tabs.Tab"]);
var remarkHeadings = ({ exportName = "__toc", isRemoteContent }) => {
  const headingMeta = {
    headings: []
  };
  const slugger = new Slugger();
  return (tree, file, done) => {
    const PartialComponentToHeadingsName = /* @__PURE__ */ Object.create(null);
    visit(
      tree,
      [
        "heading",
        // push partial component's __toc export name to headings list
        "mdxJsxFlowElement",
        // verify .md/.mdx exports and attach named __toc export
        "mdxjsEsm"
      ],
      (node, _index, parent) => {
        var _a;
        if (node.type === "heading") {
          const hasJsxInH1 = node.depth === 1 && node.children.some(
            (child) => child.type === "mdxJsxTextElement"
          );
          if (hasJsxInH1) {
            headingMeta.hasJsxInH1 = true;
          }
          const value = getFlattenedValue(node);
          node.data || (node.data = {});
          const headingProps = (_a = node.data).hProperties || (_a.hProperties = {});
          const id = slugger.slug(headingProps.id || value);
          headingProps.id = id;
          if (!SKIP_FOR_PARENT_NAMES.has(parent.name)) {
            headingMeta.headings.push({
              depth: node.depth,
              value,
              id
            });
          }
          return;
        }
        if (isRemoteContent) {
        } else if (node.type === "mdxjsEsm") {
          for (const child of node.data.estree.body) {
            if (child.type !== "ImportDeclaration")
              continue;
            const importPath = child.source.value;
            const isMdxImport = MARKDOWN_EXTENSION_REGEX.test(importPath);
            if (!isMdxImport)
              continue;
            const componentName = child.specifiers.find(
              (o) => o.type === "ImportDefaultSpecifier"
            )?.local.name;
            if (!componentName)
              continue;
            const { length } = Object.keys(PartialComponentToHeadingsName);
            const exportAsName = `${exportName}${length}`;
            PartialComponentToHeadingsName[componentName] = exportAsName;
            child.specifiers.push({
              type: "ImportSpecifier",
              imported: { type: "Identifier", name: exportName },
              local: { type: "Identifier", name: exportAsName }
            });
          }
        } else {
          const headingsName = PartialComponentToHeadingsName[node.name];
          if (headingsName) {
            headingMeta.headings.push(headingsName);
          }
        }
      }
    );
    file.data.hasJsxInH1 = headingMeta.hasJsxInH1;
    file.data.title = headingMeta.headings.find(
      (h) => typeof h !== "string" && h.depth === 1
    )?.value;
    if (isRemoteContent) {
      file.data.headings = headingMeta.headings;
      done();
      return;
    }
    const headingElements = headingMeta.headings.map(
      (heading) => typeof heading === "string" ? {
        type: "SpreadElement",
        argument: { type: "Identifier", name: heading }
      } : {
        type: "ObjectExpression",
        properties: Object.entries(heading).map(([key, value]) => ({
          type: "Property",
          kind: "init",
          key: { type: "Identifier", name: key },
          value: { type: "Literal", value }
        }))
      }
    );
    tree.children.push({
      type: "mdxjsEsm",
      data: {
        estree: {
          body: [
            {
              type: "ExportNamedDeclaration",
              specifiers: [],
              declaration: {
                type: "VariableDeclaration",
                kind: "const",
                declarations: [
                  {
                    type: "VariableDeclarator",
                    id: { type: "Identifier", name: exportName },
                    init: { type: "ArrayExpression", elements: headingElements }
                  }
                ]
              }
            }
          ]
        }
      }
    });
    done();
  };
};
export {
  remarkHeadings
};
